@@ -16,14 +16,15 @@ import logging
 
 
 __title__ = 'MolVS'
-__version__ = '0.0.1'
+__version__ = '0.0.2'
 __author__ = 'Matt Swain'
 __email__ = 'm.swain@me.com'
 __license__ = 'MIT'
 __copyright__ = 'Copyright 2014 Matt Swain'
 
 
-from .standardize import Standardizer, standardize_smiles
+from .standardize import Standardizer, standardize_smiles, enumerate_tautomers_smiles, canonicalize_tautomer_smiles
+from .validate import Validator, validate_smiles
 from .errors import MolVSError, StandardizeError, ValidateError
 
 
